# Sets up the data in R

library(R2admb)

### create matrix model depending on the input in the global env


if (linf_var == "Density") {
linf.formula =  ~ Density_first_year}

if (linf_var == "Cohort") {
	linf.formula =  ~ Cohort
	}

if (linf_var == "Const") {
		linf.formula =  ~ 1
		}
		
if (k_var == "Density") {
k.formula =  ~ Density_first_year
}

if (k_var == "Cohort") {
	k.formula =  ~ Cohort
	}

if (k_var == "Const") {
		k.formula =  ~ 1
		}
		
		
t0.formula = ~ 1

linf.mm = model.matrix(linf.formula,data=data_growth)
k.mm = model.matrix(k.formula,data=data_growth)
t0.mm = model.matrix(t0.formula,data = data_growth)





## Density is not used in this work

X = linf.mm

if (linf_var == "Density") {  
X[,2]=X[,2]/1000
}

X_k0 = k.mm

if (k_var =="Density") {
X_k0 = k.mm
}
X_t0 = t0.mm

#X=X[,c(1,20)]
#X_k0=as.matrix(X_k0[,1])

#####
## ordering Marks (tag of individuals)
diffmark  = diff(data_growth$Mark)
diffmark  = ifelse(diffmark==0,0,1)



psi_fixed.vett = seq(0,1,0.1) # vectors of psi values to be fitted/tested
AIC.vett = matrix(0,length(psi_fixed.vett),2)  # create an empty matrix for later storing of AIC model values

synth.list.18 = vector("list", length(psi_fixed.vett)) # list for storing results

for (i in 1:length(psi_fixed.vett)) { # loop for every value of psi

psi_fixed = psi_fixed.vett[i]  # takes value of psi

### writes the dat file - remember that write_dat is in ADMButil.s

write_dat("m_grow18",list(n=nrow(data_growth),
		length=data_growth$Length,
		age=data_growth$Age,
                total_marks=length(unique(data_growth$Mark)),
		start=c(1,which(diffmark>0)+1),
		stop=c(which(diffmark>0),nrow(data_growth)),
		q=ncol(X),
		X=X,
		q_k0=ncol(X_k0),
		X_k0=X_k0,
		q_t0=ncol(X_t0),
X_t0=X_t0,psi_fixed = psi_fixed,
check=12345))  ### the last is fo checking whether the .dat file is produced with not errors


#source("admb -r m_grow18") 

system("./m_grow18 -est")    ### calls m_grow18 with no standard deviations computed. To compute standard deviations, delete -est

results.par = par_read("m_grow18.par")  # reads the parameter estimates and other quantities (number of parameters, gradient given by ADMB etc.)

assign(paste("results.par.zak0.18psi.",psi_fixed.vett[i],sep=""), results.par) ## assigns a name to the model

pred = read.table("m_grow18.rep")  # .rep contains the predictions (using the model) of data used for fitting the model

assign(paste("results.rep.zak0.18psi.",psi_fixed.vett[i],sep=""), pred) #assigns a name to model predictions

prov.AIC = -2*results.par$n_par - 2*results.par$loglik #compute AIC (the change of sign is due to a bug in ADMButils)
AIC.vett[i,1] = psi_fixed
AIC.vett[i,2] = prov.AIC
prov.gradient = results.par$gradient

assign(paste("results.AIC.zak0.18psi.",psi_fixed.vett[i],sep=""), prov.AIC)

assign(paste("results.grad.zak0.18psi.",psi_fixed.vett[i],sep=""), prov.gradient)

# here below I assign to the list synth.list.18 the output of the model fitting

synth.list.18[[i]]$name = paste("results.par.zak0.18psi.",psi_fixed.vett[i],sep="")
synth.list.18[[i]]$AIC = prov.AIC
synth.list.18[[i]]$par = results.par 
synth.list.18[[i]]$rep = pred
synth.list.18[[i]]$grad = prov.gradient
}

best.psi = AIC.vett[which(AIC.vett[,2] == (min(AIC.vett[,2]))),1]

